@@ -15,10 +15,16 @@ package Image::ExifTool::Shortcuts;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.05';
+$VERSION = '1.07';
 
 # this is a special table used to define command-line shortcuts
 %Image::ExifTool::Shortcuts::Main = (
+    # this shortcut allows the three common date/time tags to be shifted at once
+    AllDates => [
+        'DateTimeOriginal',
+        'CreateDate',
+        'ModifyDate',
+    ],
     # This is a shortcut to some common information which is useful in most images
     Common => [
         'FileName',
@@ -155,6 +161,46 @@ $VERSION = '1.05';
         'CFAPattern',
         'ThumbnailImageIFD',
     ],
+    # This shortcut may be useful when copying tags between files to either
+    # copy the maker notes as a block or prevent it from being copied
+    MakerNotes => [
+        'MakerNoteCanon', 
+        'MakerNoteCasio', 
+        'MakerNoteCasio2', 
+        'MakerNoteFujiFilm', 
+        'MakerNoteJVC', 
+        'MakerNoteJVCText', 
+        'MakerNoteKodak1a', 
+        'MakerNoteKodak1b', 
+        'MakerNoteKodak2', 
+        'MakerNoteKodak3', 
+        'MakerNoteKodak4', 
+        'MakerNoteKodak5', 
+        'MakerNoteKodak6a', 
+        'MakerNoteKodak6b', 
+        'MakerNoteKodakUnknown', 
+        'MakerNoteKyocera', 
+        'MakerNoteMinolta', 
+        'MakerNoteMinolta2', 
+        'MakerNoteMinolta3', 
+        'MakerNoteMinolta4', 
+        'MakerNoteNikon', 
+        'MakerNoteNikon2', 
+        'MakerNoteNikon3', 
+        'MakerNoteOlympus', 
+        'MakerNoteLeica', 
+        'MakerNotePanasonic', 
+        'MakerNotePanasonic2', 
+        'MakerNotePentax', 
+        'MakerNoteRicoh', 
+        'MakerNoteRicohText', 
+        'MakerNoteSanyo', 
+        'MakerNoteSigma', 
+        'MakerNoteSony', 
+        'MakerNoteSonySRF', 
+        'MakerNoteSonySR2', 
+        'MakerNoteUnknown',
+    ],
 );
 
 # load user-defined shortcuts if available
@@ -188,10 +234,11 @@ This module contains definitions for tag name shortcuts used by
 Image::ExifTool.  You can customize this file to add your own shortcuts.
 
 Individual users may also add their own shortcuts to the .ExifTool_config
-file in their home directory.  The shortcuts are defined in a hash called
-%Image::ExifTool::Shortcuts::UserDefined.  The keys of the hash are the
-shortcut names, and the elements are either tag names or references to lists
-of tag names.
+file in their home directory (or the directory specified by the
+EXIFTOOL_HOME environment variable).  The shortcuts are defined in a hash
+called %Image::ExifTool::Shortcuts::UserDefined.  The keys of the hash are
+the shortcut names, and the elements are either tag names or references to
+lists of tag names.
 
 An example shortcut definition in .ExifTool_config:
 
