@@ -6,6 +6,8 @@
 # Revisions:    04/06/2004  - P. Harvey Created
 #
 # References:   1) http://www.cybercom.net/~dcoffin/dcraw/
+#               2) http://homepage3.nifty.com/kamisaka/makernote/makernote_sony.htm
+#               3) Thomas Bodenmann private communication
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Sony;
@@ -14,12 +16,15 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
+use Image::ExifTool::Minolta;
 
-$VERSION = '1.05';
+$VERSION = '1.08';
 
 sub ProcessSRF($$$);
 sub ProcessSR2($$$);
 
+my %sonyLensIDs;    # filled in based on Minolta LensID's
+
 %Image::ExifTool::Sony::Main = (
     WRITE_PROC => \&Image::ExifTool::Exif::WriteExif,
     CHECK_PROC => \&Image::ExifTool::Exif::CheckExif,
@@ -32,6 +37,34 @@ sub ProcessSR2($$$);
         },
     },
     0xb020 => 'ColorModeSetting', #PH
+    0xb027 => { #2
+        Name => 'LensID',
+        PrintConv => \%sonyLensIDs,
+    },
+    0xb028 => { #2
+        # (used by the DSLR-A100)
+        Name => 'MinoltaMakerNote',
+        Flags => 'SubIFD',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Minolta::Main',
+            Start => '$val',
+        },
+    },
+    0xb040 => { #2
+        Name => 'Macro',
+        PrintConv => { 0 => 'Off', 1 => 'On' },
+    },
+    0xb041 => { #2
+        Name => 'ExposureMode',
+        PrintConv => {
+            0 => 'Auto',
+            6 => 'Program',
+            7 => 'Aperture Priority',
+            8 => 'Shutter Priority',
+            9 => 'Night Scene',
+            15 => 'Manual',
+        },
+    },
 );
 
 # tag table for Sony RAW Format
@@ -105,6 +138,16 @@ sub ProcessSR2($$$);
     0x7770 => 'ColorMode', #PH
 );
 
+# fill in Sony LensID lookup based on Minolta values
+{
+    my $id;
+    foreach $id (keys %Image::ExifTool::Minolta::minoltaLensIDs) {
+        # higher numbered lenses are missing last digit of ID
+        my $sonyID = ($id < 10000) ? $id : int($id / 10);
+        $sonyLensIDs{$sonyID} = $Image::ExifTool::Minolta::minoltaLensIDs{$id};
+    }
+}
+
 #------------------------------------------------------------------------------
 # decrypt Sony data (ref 1)
 # Inputs: 0) data reference, 1) start offset, 2) data length, 3) decryption key
@@ -242,7 +285,7 @@ sub ProcessSR2($$$)
             );
             my $subTable = Image::ExifTool::GetTagTable('Image::ExifTool::Sony::SR2SubIFD');
             $result = $exifTool->ProcessDirectory(\%dirInfo, $subTable);
-            
+
         } else {
             $exifTool->Warn('Error reading SR2 data');
         }
@@ -289,8 +332,14 @@ under the same terms as Perl itself.
 
 =item L<http://www.cybercom.net/~dcoffin/dcraw/>
 
+=item L<http://homepage3.nifty.com/kamisaka/makernote/makernote_sony.htm>
+
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Thomas Bodenmann for providing information about the LensID's.
+
 =head1 SEE ALSO
 
 L<Image::ExifTool::TagNames/Sony Tags>,
